@@ -192,7 +192,10 @@ class CommonBrowserView(BrowserView):
         if event.portal_type != 'Event' and event.portal_type != 'Media Event':
             return False
         else:
-            return event.end() < time.time()
+            if event.end() is not None:
+                return event.end() < time.time()
+            else:
+                return event.start() < time.time()
     
     def getCurrentTime(self):
         """
@@ -224,11 +227,11 @@ class CommonBrowserView(BrowserView):
         
         dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A %d %B %Y') or event.end().strftime('%A %d %B %Y')) or "%s to %s"%(event.start().strftime('%A %d %B %Y'), event.end().strftime('%A %d %B %Y')))
         
-        openingHour = event.start() is not None and event.start().strftime('%H:%M') or "00:00"
-        closingHour = event.end() is not None and event.end().strftime('%H:%M') or "00:00"
-        hoursExist = openingHour != closingHour
+        openingHour = event.start() is not None and event.start().strftime('%H:%M') or ""
+        closingHour = event.end() is not None and event.end().strftime('to %H:%M') or ""
+        hoursExist = 'to %s'%openingHour != closingHour
         
-        hours = hoursExist and ', <span class="hours">%s to %s</span>'%(openingHour, closingHour) or ''
+        hours = hoursExist and ', <span class="hours">%s %s</span>'%(openingHour, closingHour) or ''
         
         finalDates = finalDatesFmt%{'class': self.isEventPast(event) and 'past' or 'future', 'dates': dates, 'hours': hours, 'exceptions':exceptions}
         
